==> nicegui-0.9.26.tar.gz: nicegui-0.9.26/nicegui/elements/tree.py <==
from typing import Callable, Optional

import justpy as jp

from nicegui.events import ValueChangeEventArguments, handle_event

from .element import Element


class Tree(Element):
    def __init__(self, nodes: list, *,
                 node_key: str = 'id',
                 label_key: str = 'label',
                 children_key: str = 'children',
                 on_select: Optional[Callable] = None):
        """Tree

        Display hierarchical data using Quasar's `QTree <https://v1.quasar.dev/vue-components/tree>`_ component.

        If using IDs, make sure they are unique within the whole tree.

        :param nodes: hierarchical list of node objects
        :param node_key: property name of each node object that holds its unique id (default: "id")
        :param label_key: property name of each node object that holds its label (default: "label")
        :param children_key: property name of each node object that holds its list of children (default: "children")
        :param on_select: callback which is invoked when the node selection changes
        """

        view = jp.QTree(nodes=nodes, node_key=node_key, label_key=label_key, children_key=children_key, temp=False)
        super().__init__(view)

        def process_event(view, event) -> Optional[bool]:
            arguments = ValueChangeEventArguments(sender=self, socket=event.get('websocket'), value=event.get('value'))
            return handle_event(on_select, arguments)

        view.on('update:selected', process_event)
        view.on('update:expanded', lambda *_: self.update())
        view.on('update:ticked', lambda *_: self.update())

==> nicegui-1.0.2.tar.gz: nicegui-1.0.2/nicegui/elements/tree.py <==
from typing import Callable, Optional

from nicegui.events import ValueChangeEventArguments, handle_event

from ..element import Element


class Tree(Element):

    def __init__(self, nodes: list, *,
                 node_key: str = 'id',
                 label_key: str = 'label',
                 children_key: str = 'children',
                 on_select: Optional[Callable] = None) -> None:
        """Tree

        Display hierarchical data using Quasar's `QTree <https://v1.quasar.dev/vue-components/tree>`_ component.

        If using IDs, make sure they are unique within the whole tree.

        :param nodes: hierarchical list of node objects
        :param node_key: property name of each node object that holds its unique id (default: "id")
        :param label_key: property name of each node object that holds its label (default: "label")
        :param children_key: property name of each node object that holds its list of children (default: "children")
        :param on_select: callback which is invoked when the node selection changes
        """
        super().__init__('q-tree')
        self._props['nodes'] = nodes
        self._props['node-key'] = node_key
        self._props['label-key'] = label_key
        self._props['children-key'] = children_key
        self._props['selected'] = []

        def handle_selected(msg):
            handle_event(on_select, ValueChangeEventArguments(sender=self, client=self.client, value=msg['args']))
        self.on('update:selected', handle_selected)
